@@ -35,7 +35,6 @@ extensions = [
     "sphinxext.rediraffe",
     "myst_parser",
     "linkify_issues",
-    "sphinx_toctree_autodoc_fix",
 ]
 
 myst_enable_extensions = [
@@ -83,6 +82,10 @@ html_theme_options: Dict[str, Union[str, List[Dict[str, str]]]] = {
             "class": "",
         },
     ],
+    "source_repository": f"{about['__github__']}/",
+    "source_branch": "master",
+    "source_directory": "docs/",
+    "announcement": "<em>Friendly reminder:</em> 📌 Pin the package, libtmux is pre-1.0 and APIs will be <a href='/history.html'>changing</a> throughout 2022-2023.",
 }
 html_sidebars = {
     "**": [
@@ -101,6 +104,7 @@ issue_url_tpl = f'{about["__github__"]}/issues/{{issue_id}}'
 # sphinx.ext.autodoc
 autoclass_content = "both"
 autodoc_member_order = "bysource"
+toc_object_entries_show_parents = "hide"
 
 # sphinx-copybutton
 copybutton_prompt_text = (
